---
title: <span class="badge object-type-enum"></span> ComparisonOperation
---
# <span class="badge object-type-enum"></span> ComparisonOperation

Compare two values

## Definition

```python
class ComparisonOperation(enum.StrEnum):
    """
    Compare two values
    """

    EQ = "eq"
    NEQ = "neq"
    LT = "lt"
    LTE = "lte"
    GT = "gt"
    GTE = "gte"
```
